@@ -1,8 +1,6 @@
 # --
 # Kernel/Modules/AgentTicketSearch.pm - Utilities for tickets
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: AgentTicketSearch.pm,v 1.145.2.2 2012-08-06 07:33:37 mg Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -26,9 +24,6 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.145.2.2 $) [1];
-
 sub new {
     my ( $Type, %Param ) = @_;
 
@@ -37,12 +32,12 @@ sub new {
     bless( $Self, $Type );
 
     # check needed objects
-    for (
+    for my $Needed (
         qw(ParamObject DBObject TicketObject LayoutObject LogObject ConfigObject MainObject EncodeObject)
         )
     {
-        if ( !$Self->{$_} ) {
-            $Self->{LayoutObject}->FatalError( Message => "Got no $_!" );
+        if ( !$Self->{$Needed} ) {
+            $Self->{LayoutObject}->FatalError( Message => "Got no $Needed!" );
         }
     }
     $Self->{CustomerUserObject}  = Kernel::System::CustomerUser->new(%Param);
@@ -88,7 +83,7 @@ sub new {
     # get the dynamic fields for ticket object
     $Self->{DynamicField} = $Self->{DynamicFieldObject}->DynamicFieldListGet(
         Valid       => 1,
-        ObjectType  => ['Ticket', 'Article'],
+        ObjectType  => [ 'Ticket', 'Article' ],
         FieldFilter => $Self->{DynamicFieldFilter} || {},
     );
 
@@ -176,9 +171,10 @@ sub Run {
 
     # get search string params (get submitted params)
     else {
-        for (
+        for my $Key (
             qw(TicketNumber Title From To Cc Subject Body CustomerID CustomerUserLogin StateType
-            Agent ResultForm TimeSearchType ChangeTimeSearchType CloseTimeSearchType UseSubQueues
+            Agent ResultForm TimeSearchType ChangeTimeSearchType CloseTimeSearchType EscalationTimeSearchType
+            UseSubQueues
             ArticleTimeSearchType SearchInArchive
             Fulltext ShownAttributes
             ArticleCreateTimePointFormat ArticleCreateTimePoint
@@ -205,22 +201,28 @@ sub Run {
             TicketCloseTimeStartYear
             TicketCloseTimeStop TicketCloseTimeStopDay TicketCloseTimeStopMonth
             TicketCloseTimeStopYear
+            TicketEscalationTimePointFormat TicketEscalationTimePoint
+            TicketEscalationTimePointStart
+            TicketEscalationTimeStart TicketEscalationTimeStartDay TicketEscalationTimeStartMonth
+            TicketEscalationTimeStartYear
+            TicketEscalationTimeStop TicketEscalationTimeStopDay TicketEscalationTimeStopMonth
+            TicketEscalationTimeStopYear
             )
             )
         {
 
             # get search string params (get submitted params)
-            $GetParam{$_} = $Self->{ParamObject}->GetParam( Param => $_ );
+            $GetParam{$Key} = $Self->{ParamObject}->GetParam( Param => $Key );
 
             # remove white space on the start and end
-            if ( $GetParam{$_} ) {
-                $GetParam{$_} =~ s/\s+$//g;
-                $GetParam{$_} =~ s/^\s+//g;
+            if ( $GetParam{$Key} ) {
+                $GetParam{$Key} =~ s/\s+$//g;
+                $GetParam{$Key} =~ s/^\s+//g;
             }
         }
 
         # get array params
-        for (
+        for my $Key (
             qw(StateIDs StateTypeIDs QueueIDs PriorityIDs OwnerIDs
             CreatedQueueIDs CreatedUserIDs WatchUserIDs ResponsibleIDs
             TypeIDs ServiceIDs SLAIDs LockIDs)
@@ -228,19 +230,19 @@ sub Run {
         {
 
             # get search array params (get submitted params)
-            my @Array = $Self->{ParamObject}->GetArray( Param => $_ );
+            my @Array = $Self->{ParamObject}->GetArray( Param => $Key );
             if (@Array) {
-                $GetParam{$_} = \@Array;
+                $GetParam{$Key} = \@Array;
             }
         }
 
-        # get Dynamic fields form param object
+        # get Dynamic fields from param object
         # cycle trough the activated Dynamic Fields for this screen
         DYNAMICFIELD:
         for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
             next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
 
-            # extract the dynamic field value form the web request
+            # extract the dynamic field value from the web request
             my $DynamicFieldValue = $Self->{BackendObject}->SearchFieldValueGet(
                 DynamicFieldConfig     => $DynamicFieldConfig,
                 ParamObject            => $Self->{ParamObject},
@@ -248,7 +250,7 @@ sub Run {
                 LayoutObject           => $Self->{LayoutObject},
             );
 
-            # set the comple value structure in GetParam to store it later in the search profile
+            # set the complete value structure in GetParam to store it later in the search profile
             if ( IsHashRefWithData($DynamicFieldValue) ) {
                 %GetParam = ( %GetParam, %{$DynamicFieldValue} );
             }
@@ -299,6 +301,17 @@ sub Run {
         $GetParam{'CloseTimeSearchType::TimeSlot'} = 1;
     }
 
+    # get escalation time option
+    if ( !$GetParam{EscalationTimeSearchType} ) {
+        $GetParam{'EscalationTimeSearchType::None'} = 1;
+    }
+    elsif ( $GetParam{EscalationTimeSearchType} eq 'TimePoint' ) {
+        $GetParam{'EscalationTimeSearchType::TimePoint'} = 1;
+    }
+    elsif ( $GetParam{EscalationTimeSearchType} eq 'TimeSlot' ) {
+        $GetParam{'EscalationTimeSearchType::TimeSlot'} = 1;
+    }
+
     # set result form env
     if ( !$GetParam{ResultForm} ) {
         $GetParam{ResultForm} = '';
@@ -364,13 +377,11 @@ sub Run {
             # do nothing with time stuff
         }
         elsif ( $GetParam{ArticleTimeSearchType} eq 'TimeSlot' ) {
-            for (qw(Month Day)) {
-                $GetParam{"ArticleCreateTimeStart$_"}
-                    = sprintf( "%02d", $GetParam{"ArticleCreateTimeStart$_"} );
-            }
-            for (qw(Month Day)) {
-                $GetParam{"ArticleCreateTimeStop$_"}
-                    = sprintf( "%02d", $GetParam{"ArticleCreateTimeStop$_"} );
+            for my $Key (qw(Month Day)) {
+                $GetParam{"ArticleCreateTimeStart$Key"}
+                    = sprintf( "%02d", $GetParam{"ArticleCreateTimeStart$Key"} );
+                $GetParam{"ArticleCreateTimeStop$Key"}
+                    = sprintf( "%02d", $GetParam{"ArticleCreateTimeStop$Key"} );
             }
             if (
                 $GetParam{ArticleCreateTimeStartDay}
@@ -438,13 +449,11 @@ sub Run {
             # do nothing with time stuff
         }
         elsif ( $GetParam{TimeSearchType} eq 'TimeSlot' ) {
-            for (qw(Month Day)) {
-                $GetParam{"TicketCreateTimeStart$_"}
-                    = sprintf( "%02d", $GetParam{"TicketCreateTimeStart$_"} );
-            }
-            for (qw(Month Day)) {
-                $GetParam{"TicketCreateTimeStop$_"}
-                    = sprintf( "%02d", $GetParam{"TicketCreateTimeStop$_"} );
+            for my $Key (qw(Month Day)) {
+                $GetParam{"TicketCreateTimeStart$Key"}
+                    = sprintf( "%02d", $GetParam{"TicketCreateTimeStart$Key"} );
+                $GetParam{"TicketCreateTimeStop$Key"}
+                    = sprintf( "%02d", $GetParam{"TicketCreateTimeStop$Key"} );
             }
             if (
                 $GetParam{TicketCreateTimeStartDay}
@@ -512,13 +521,11 @@ sub Run {
             # do nothing on time stuff
         }
         elsif ( $GetParam{ChangeTimeSearchType} eq 'TimeSlot' ) {
-            for (qw(Month Day)) {
-                $GetParam{"TicketChangeTimeStart$_"}
-                    = sprintf( "%02d", $GetParam{"TicketChangeTimeStart$_"} );
-            }
-            for (qw(Month Day)) {
-                $GetParam{"TicketChangeTimeStop$_"}
-                    = sprintf( "%02d", $GetParam{"TicketChangeTimeStop$_"} );
+            for my $Key (qw(Month Day)) {
+                $GetParam{"TicketChangeTimeStart$Key"}
+                    = sprintf( "%02d", $GetParam{"TicketChangeTimeStart$Key"} );
+                $GetParam{"TicketChangeTimeStop$Key"}
+                    = sprintf( "%02d", $GetParam{"TicketChangeTimeStop$Key"} );
             }
             if (
                 $GetParam{TicketChangeTimeStartDay}
@@ -586,13 +593,11 @@ sub Run {
             # do nothing on time stuff
         }
         elsif ( $GetParam{CloseTimeSearchType} eq 'TimeSlot' ) {
-            for (qw(Month Day)) {
-                $GetParam{"TicketCloseTimeStart$_"}
-                    = sprintf( "%02d", $GetParam{"TicketCloseTimeStart$_"} );
-            }
-            for (qw(Month Day)) {
-                $GetParam{"TicketCloseTimeStop$_"}
-                    = sprintf( "%02d", $GetParam{"TicketCloseTimeStop$_"} );
+            for my $Key (qw(Month Day)) {
+                $GetParam{"TicketCloseTimeStart$Key"}
+                    = sprintf( "%02d", $GetParam{"TicketCloseTimeStart$Key"} );
+                $GetParam{"TicketCloseTimeStop$Key"}
+                    = sprintf( "%02d", $GetParam{"TicketCloseTimeStop$Key"} );
             }
             if (
                 $GetParam{TicketCloseTimeStartDay}
@@ -654,6 +659,78 @@ sub Run {
             }
         }
 
+        # get escalation time settings
+        if ( !$GetParam{EscalationTimeSearchType} ) {
+
+            # do nothing on time stuff
+        }
+        elsif ( $GetParam{EscalationTimeSearchType} eq 'TimeSlot' ) {
+            for my $Key (qw(Month Day)) {
+                $GetParam{"TicketEscalationTimeStart$Key"}
+                    = sprintf( "%02d", $GetParam{"TicketEscalationTimeStart$Key"} );
+                $GetParam{"TicketEscalationTimeStop$Key"}
+                    = sprintf( "%02d", $GetParam{"TicketEscalationTimeStop$Key"} );
+            }
+            if (
+                $GetParam{TicketEscalationTimeStartDay}
+                && $GetParam{TicketEscalationTimeStartMonth}
+                && $GetParam{TicketEscalationTimeStartYear}
+                )
+            {
+                $GetParam{TicketEscalationTimeNewerDate}
+                    = $GetParam{TicketEscalationTimeStartYear} . '-'
+                    . $GetParam{TicketEscalationTimeStartMonth} . '-'
+                    . $GetParam{TicketEscalationTimeStartDay}
+                    . ' 00:00:00';
+            }
+            if (
+                $GetParam{TicketEscalationTimeStopDay}
+                && $GetParam{TicketEscalationTimeStopMonth}
+                && $GetParam{TicketEscalationTimeStopYear}
+                )
+            {
+                $GetParam{TicketEscalationTimeOlderDate}
+                    = $GetParam{TicketEscalationTimeStopYear} . '-'
+                    . $GetParam{TicketEscalationTimeStopMonth} . '-'
+                    . $GetParam{TicketEscalationTimeStopDay}
+                    . ' 23:59:59';
+            }
+        }
+        elsif ( $GetParam{EscalationTimeSearchType} eq 'TimePoint' ) {
+            if (
+                $GetParam{TicketEscalationTimePoint}
+                && $GetParam{TicketEscalationTimePointStart}
+                && $GetParam{TicketEscalationTimePointFormat}
+                )
+            {
+                my $Time = 0;
+                if ( $GetParam{TicketEscalationTimePointFormat} eq 'minute' ) {
+                    $Time = $GetParam{TicketEscalationTimePoint};
+                }
+                elsif ( $GetParam{TicketEscalationTimePointFormat} eq 'hour' ) {
+                    $Time = $GetParam{TicketEscalationTimePoint} * 60;
+                }
+                elsif ( $GetParam{TicketEscalationTimePointFormat} eq 'day' ) {
+                    $Time = $GetParam{TicketEscalationTimePoint} * 60 * 24;
+                }
+                elsif ( $GetParam{TicketEscalationTimePointFormat} eq 'week' ) {
+                    $Time = $GetParam{TicketEscalationTimePoint} * 60 * 24 * 7;
+                }
+                elsif ( $GetParam{TicketEscalationTimePointFormat} eq 'month' ) {
+                    $Time = $GetParam{TicketEscalationTimePoint} * 60 * 24 * 30;
+                }
+                elsif ( $GetParam{TicketEscalationTimePointFormat} eq 'year' ) {
+                    $Time = $GetParam{TicketEscalationTimePoint} * 60 * 24 * 365;
+                }
+                if ( $GetParam{TicketEscalationTimePointStart} eq 'Before' ) {
+                    $GetParam{TicketEscalationTimeOlderMinutes} = $Time;
+                }
+                else {
+                    $GetParam{TicketEscalationTimeNewerMinutes} = $Time;
+                }
+            }
+        }
+
         # Special behaviour for the fulltext search toolbar module:
         # - Check full text string to see if contents is a ticket number.
         # - If exists and not in print or CSV mode, redirect to the ticket.
@@ -682,8 +759,8 @@ sub Run {
         # prepare full text search
         if ( $GetParam{Fulltext} ) {
             $GetParam{ContentSearch} = 'OR';
-            for (qw(From To Cc Subject Body)) {
-                $GetParam{$_} = $GetParam{Fulltext};
+            for my $Key (qw(From To Cc Subject Body)) {
+                $GetParam{$Key} = $GetParam{Fulltext};
             }
         }
 
@@ -719,7 +796,7 @@ sub Run {
             next DYNAMICFIELD
                 if !$AttributeLookup{ 'LabelSearch_DynamicField_' . $DynamicFieldConfig->{Name} };
 
-            # extract the dynamic field value form the profile
+            # extract the dynamic field value from the profile
             my $SearchParameter = $Self->{BackendObject}->SearchFieldParameterBuild(
                 DynamicFieldConfig => $DynamicFieldConfig,
                 Profile            => \%GetParam,
@@ -752,14 +829,28 @@ sub Run {
 
         # CSV output
         if ( $GetParam{ResultForm} eq 'CSV' ) {
-            my @CSVHead;
-            my @CSVData;
 
-            for (@ViewableTicketIDs) {
+            # create head (actual head and head for data fill)
+            my @TmpCSVHead = @{ $Self->{Config}->{SearchCSVData} };
+            my @CSVHead = @{ $Self->{Config}->{SearchCSVData} };
+
+            # include the selected dynamic fields in CVS results
+            DYNAMICFIELD:
+            for my $DynamicFieldConfig ( @{ $Self->{CSVDynamicField} } ) {
+                next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
+                next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
+                next DYNAMICFIELD if $DynamicFieldConfig->{Name} eq '';
+
+                push @TmpCSVHead, 'DynamicField_' . $DynamicFieldConfig->{Name};
+                push @CSVHead, $DynamicFieldConfig->{Label};
+            }
+
+            my @CSVData;
+            for my $TicketID (@ViewableTicketIDs) {
 
                 # get first article data
                 my %Data = $Self->{TicketObjectSearch}->ArticleFirstArticle(
-                    TicketID      => $_,
+                    TicketID      => $TicketID,
                     Extended      => 1,
                     DynamicFields => 1,
                 );
@@ -773,7 +864,7 @@ sub Run {
                 # get whole article (if configured!)
                 if ( $Self->{Config}->{SearchArticleCSVTree} ) {
                     my @Article = $Self->{TicketObjectSearch}->ArticleGet(
-                        TicketID      => $_,
+                        TicketID      => $TicketID,
                         DynamicFields => 0,
                     );
                     for my $Articles (@Article) {
@@ -804,29 +895,16 @@ sub Run {
                     %Data,
                     %UserInfo,
                     AccountedTime =>
-                        $Self->{TicketObjectSearch}->TicketAccountedTimeGet( TicketID => $_ ),
+                        $Self->{TicketObjectSearch}
+                        ->TicketAccountedTimeGet( TicketID => $TicketID ),
                 );
 
-                # csv quote
-                if ( !@CSVHead ) {
-                    @CSVHead = @{ $Self->{Config}->{SearchCSVData} };
-
-                    # include the selected dynamic fields on CVS resutls
-                    DYNAMICFIELD:
-                    for my $DynamicFieldConfig ( @{ $Self->{CSVDynamicField} } ) {
-                        next DYNAMICFIELD if !IsHashRefWithData($DynamicFieldConfig);
-                        next DYNAMICFIELD if !$DynamicFieldConfig->{Name};
-                        next DYNAMICFIELD if $DynamicFieldConfig->{Name} eq '';
-
-                        push @CSVHead, 'DynamicField_' . $DynamicFieldConfig->{Name};
-                    }
-                }
                 my @Data;
-                for (@CSVHead) {
+                for my $Header (@TmpCSVHead) {
 
                     # check if header is a dynamic field and get the value from dynamic field
                     # backend
-                    if ( $_ =~ m{\A DynamicField_ ( [a-zA-Z\d]+ ) \z}xms ) {
+                    if ( $Header =~ m{\A DynamicField_ ( [a-zA-Z\d]+ ) \z}xms ) {
 
                         # loop over the dynamic fields configured for CSV output
                         DYNAMICFIELD:
@@ -838,10 +916,10 @@ sub Run {
                             # with out the 'DynamicField_' prefix
                             next DYNAMICFIELD if $DynamicFieldConfig->{Name} ne $1;
 
-                            # get the value as for print (to corretly display)
+                            # get the value as for print (to correctly display)
                             my $ValueStrg = $Self->{BackendObject}->DisplayValueRender(
                                 DynamicFieldConfig => $DynamicFieldConfig,
-                                Value              => $Info{$_},
+                                Value              => $Info{$Header},
                                 HTMLOutput         => 0,
                                 LayoutObject       => $Self->{LayoutObject},
                             );
@@ -854,7 +932,7 @@ sub Run {
 
                     # otherwise retreive data from article
                     else {
-                        push @Data, $Info{$_};
+                        push @Data, $Info{$Header};
                     }
                 }
                 push @CSVData, \@Data;
@@ -904,11 +982,11 @@ sub Run {
             $Self->{PDFObject} = Kernel::System::PDF->new( %{$Self} );
 
             my @PDFData;
-            for (@ViewableTicketIDs) {
+            for my $TicketID (@ViewableTicketIDs) {
 
                 # get first article data
                 my %Data = $Self->{TicketObjectSearch}->ArticleFirstArticle(
-                    TicketID      => $_,
+                    TicketID      => $TicketID,
                     DynamicFields => 1,
                 );
 
@@ -1086,17 +1164,21 @@ sub Run {
 
                 # start table output
                 $Self->{PDFObject}->PageNew( %PageParam, FooterRight => $Page . ' 1', );
-                for ( 2 .. $MaxPages ) {
+                PAGE:
+                for my $PageNumber ( 2 .. $MaxPages ) {
 
                     # output table (or a fragment of it)
-                    %TableParam = $Self->{PDFObject}->Table( %TableParam, );
+                    %TableParam = $Self->{PDFObject}->Table(%TableParam);
 
                     # stop output or another page
                     if ( $TableParam{State} ) {
-                        last;
+                        last PAGE;
                     }
                     else {
-                        $Self->{PDFObject}->PageNew( %PageParam, FooterRight => $Page . ' ' . $_, );
+                        $Self->{PDFObject}->PageNew(
+                            %PageParam,
+                            FooterRight => $Page . ' ' . $PageNumber,
+                        );
                     }
                 }
 
@@ -1139,6 +1221,13 @@ sub Run {
         }
         else {
 
+            # redirect to the ticketzoom if result of the search is only one
+            if ( scalar @ViewableTicketIDs eq 1 ) {
+                return $Self->{LayoutObject}->Redirect(
+                    OP => "Action=AgentTicketZoom;TicketID=$ViewableTicketIDs[0]",
+                );
+            }
+
             # start html page
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
@@ -1246,7 +1335,7 @@ sub Run {
                     next if !$Self->{Config}->{Defaults}->{$Key};
                     next if $Key eq 'DynamicField';
 
-                    if ( $Key =~ /^(Ticket|Article)(Create|Change|Close)/ ) {
+                    if ( $Key =~ /^(Ticket|Article)(Create|Change|Close|Escalation)/ ) {
                         my @Items = split /;/, $Self->{Config}->{Defaults}->{$Key};
                         for my $Item (@Items) {
                             my ( $Key, $Value ) = split /=/, $Item;
@@ -1374,7 +1463,7 @@ sub Run {
 
         my $DynamicFieldSeparator = 1;
 
-        # create dynamic fields seaarch options for attribute select
+        # create dynamic fields search options for attribute select
         # cycle trough the activated Dynamic Fields for this screen
         DYNAMICFIELD:
         for my $DynamicFieldConfig ( @{ $Self->{DynamicField} } ) {
@@ -1399,7 +1488,7 @@ sub Run {
                 {
                     Key   => 'Search_DynamicField_' . $DynamicFieldConfig->{Name},
                     Value => $Self->{LayoutObject}->{LanguageObject}->Get(
-                        $DynamicFieldConfig->{Label}
+                        $DynamicFieldConfig->{Label},
                     ),
                 },
             );
@@ -1438,24 +1527,30 @@ sub Run {
 
                 # add historic values to current values (if they don't exist anymore)
                 if ( IsHashRefWithData($HistoricalValues) ) {
-                    for my $Key ( keys %{$HistoricalValues} ) {
+                    for my $Key ( sort keys %{$HistoricalValues} ) {
                         if ( !$Data->{$Key} ) {
                             $Data->{$Key} = $HistoricalValues->{$Key}
                         }
                     }
                 }
 
+                # convert possible values key => value to key => key for ACLs usign a Hash slice
+                my %AclData = %{$Data};
+                @AclData{ keys %AclData } = keys %AclData;
+
                 # set possible values filter from ACLs
                 my $ACL = $Self->{TicketObject}->TicketAcl(
                     Action        => $Self->{Action},
                     ReturnType    => 'Ticket',
                     ReturnSubType => 'DynamicField_' . $DynamicFieldConfig->{Name},
-                    Data          => $Data,
+                    Data          => \%AclData,
                     UserID        => $Self->{UserID},
                 );
                 if ($ACL) {
                     my %Filter = $Self->{TicketObject}->TicketAclData();
-                    $PossibleValuesFilter = \%Filter;
+
+                    # convert Filer key => key back to key => value using map
+                    %{$PossibleValuesFilter} = map { $_ => $Data->{$_} } keys %Filter;
                 }
             }
 
@@ -1500,6 +1595,14 @@ sub Run {
                 Key   => 'TicketCloseTimeSlot',
                 Value => 'Ticket Close Time (between)',
             },
+            {
+                Key   => 'TicketEscalationTimePoint',
+                Value => 'Ticket Escalation Time (before/after)',
+            },
+            {
+                Key   => 'TicketEscalationTimeSlot',
+                Value => 'Ticket Escalation Time (between)',
+            },
             {
                 Key   => 'ArticleCreateTimePoint',
                 Value => 'Article Create Time (before/after)',
@@ -1538,7 +1641,7 @@ sub Run {
                 UserID => $Self->{UserID},
                 Type   => 'ro',
             );
-            for my $UserID ( keys %ShownUsers ) {
+            for my $UserID ( sort keys %ShownUsers ) {
                 if ( !$Involved{$UserID} ) {
                     delete $ShownUsers{$UserID};
                 }
@@ -1710,67 +1813,7 @@ sub Run {
         );
 
         $Param{ArticleCreateTimePoint} = $Self->{LayoutObject}->BuildSelection(
-            Data => {
-                1  => ' 1',
-                2  => ' 2',
-                3  => ' 3',
-                4  => ' 4',
-                5  => ' 5',
-                6  => ' 6',
-                7  => ' 7',
-                8  => ' 8',
-                9  => ' 9',
-                10 => '10',
-                11 => '11',
-                12 => '12',
-                13 => '13',
-                14 => '14',
-                15 => '15',
-                16 => '16',
-                17 => '17',
-                18 => '18',
-                19 => '19',
-                20 => '20',
-                21 => '21',
-                22 => '22',
-                23 => '23',
-                24 => '24',
-                25 => '25',
-                26 => '26',
-                27 => '27',
-                28 => '28',
-                29 => '29',
-                30 => '30',
-                31 => '31',
-                32 => '32',
-                33 => '33',
-                34 => '34',
-                35 => '35',
-                36 => '36',
-                37 => '37',
-                38 => '38',
-                39 => '39',
-                40 => '40',
-                41 => '41',
-                42 => '42',
-                43 => '43',
-                44 => '44',
-                45 => '45',
-                46 => '46',
-                47 => '47',
-                48 => '48',
-                49 => '49',
-                50 => '50',
-                51 => '51',
-                52 => '52',
-                53 => '53',
-                54 => '54',
-                55 => '55',
-                56 => '56',
-                57 => '57',
-                58 => '58',
-                59 => '59',
-            },
+            Data       => [ 1 .. 59 ],
             Name       => 'ArticleCreateTimePoint',
             SelectedID => $GetParam{ArticleCreateTimePoint},
         );
@@ -1806,67 +1849,7 @@ sub Run {
             Format => 'DateInputFormat',
         );
         $Param{TicketCreateTimePoint} = $Self->{LayoutObject}->BuildSelection(
-            Data => {
-                1  => ' 1',
-                2  => ' 2',
-                3  => ' 3',
-                4  => ' 4',
-                5  => ' 5',
-                6  => ' 6',
-                7  => ' 7',
-                8  => ' 8',
-                9  => ' 9',
-                10 => '10',
-                11 => '11',
-                12 => '12',
-                13 => '13',
-                14 => '14',
-                15 => '15',
-                16 => '16',
-                17 => '17',
-                18 => '18',
-                19 => '19',
-                20 => '20',
-                21 => '21',
-                22 => '22',
-                23 => '23',
-                24 => '24',
-                25 => '25',
-                26 => '26',
-                27 => '27',
-                28 => '28',
-                29 => '29',
-                30 => '30',
-                31 => '31',
-                32 => '32',
-                33 => '33',
-                34 => '34',
-                35 => '35',
-                36 => '36',
-                37 => '37',
-                38 => '38',
-                39 => '39',
-                40 => '40',
-                41 => '41',
-                42 => '42',
-                43 => '43',
-                44 => '44',
-                45 => '45',
-                46 => '46',
-                47 => '47',
-                48 => '48',
-                49 => '49',
-                50 => '50',
-                51 => '51',
-                52 => '52',
-                53 => '53',
-                54 => '54',
-                55 => '55',
-                56 => '56',
-                57 => '57',
-                58 => '58',
-                59 => '59',
-            },
+            Data       => [ 1 .. 59 ],
             Name       => 'TicketCreateTimePoint',
             SelectedID => $GetParam{TicketCreateTimePoint},
         );
@@ -1903,67 +1886,7 @@ sub Run {
         );
 
         $Param{TicketChangeTimePoint} = $Self->{LayoutObject}->BuildSelection(
-            Data => {
-                1  => ' 1',
-                2  => ' 2',
-                3  => ' 3',
-                4  => ' 4',
-                5  => ' 5',
-                6  => ' 6',
-                7  => ' 7',
-                8  => ' 8',
-                9  => ' 9',
-                10 => '10',
-                11 => '11',
-                12 => '12',
-                13 => '13',
-                14 => '14',
-                15 => '15',
-                16 => '16',
-                17 => '17',
-                18 => '18',
-                19 => '19',
-                20 => '20',
-                21 => '21',
-                22 => '22',
-                23 => '23',
-                24 => '24',
-                25 => '25',
-                26 => '26',
-                27 => '27',
-                28 => '28',
-                29 => '29',
-                30 => '30',
-                31 => '31',
-                32 => '32',
-                33 => '33',
-                34 => '34',
-                35 => '35',
-                36 => '36',
-                37 => '37',
-                38 => '38',
-                39 => '39',
-                40 => '40',
-                41 => '41',
-                42 => '42',
-                43 => '43',
-                44 => '44',
-                45 => '45',
-                46 => '46',
-                47 => '47',
-                48 => '48',
-                49 => '49',
-                50 => '50',
-                51 => '51',
-                52 => '52',
-                53 => '53',
-                54 => '54',
-                55 => '55',
-                56 => '56',
-                57 => '57',
-                58 => '58',
-                59 => '59',
-            },
+            Data       => [ 1 .. 59 ],
             Name       => 'TicketChangeTimePoint',
             SelectedID => $GetParam{TicketChangeTimePoint},
         );
@@ -2000,67 +1923,7 @@ sub Run {
         );
 
         $Param{TicketCloseTimePoint} = $Self->{LayoutObject}->BuildSelection(
-            Data => {
-                1  => ' 1',
-                2  => ' 2',
-                3  => ' 3',
-                4  => ' 4',
-                5  => ' 5',
-                6  => ' 6',
-                7  => ' 7',
-                8  => ' 8',
-                9  => ' 9',
-                10 => '10',
-                11 => '11',
-                12 => '12',
-                13 => '13',
-                14 => '14',
-                15 => '15',
-                16 => '16',
-                17 => '17',
-                18 => '18',
-                19 => '19',
-                20 => '20',
-                21 => '21',
-                22 => '22',
-                23 => '23',
-                24 => '24',
-                25 => '25',
-                26 => '26',
-                27 => '27',
-                28 => '28',
-                29 => '29',
-                30 => '30',
-                31 => '31',
-                32 => '32',
-                33 => '33',
-                34 => '34',
-                35 => '35',
-                36 => '36',
-                37 => '37',
-                38 => '38',
-                39 => '39',
-                40 => '40',
-                41 => '41',
-                42 => '42',
-                43 => '43',
-                44 => '44',
-                45 => '45',
-                46 => '46',
-                47 => '47',
-                48 => '48',
-                49 => '49',
-                50 => '50',
-                51 => '51',
-                52 => '52',
-                53 => '53',
-                54 => '54',
-                55 => '55',
-                56 => '56',
-                57 => '57',
-                58 => '58',
-                59 => '59',
-            },
+            Data       => [ 1 .. 59 ],
             Name       => 'TicketCloseTimePoint',
             SelectedID => $GetParam{TicketCloseTimePoint},
         );
@@ -2095,8 +1958,46 @@ sub Run {
             Prefix => 'TicketCloseTimeStop',
             Format => 'DateInputFormat',
         );
+
+        $Param{TicketEscalationTimePoint} = $Self->{LayoutObject}->BuildSelection(
+            Data       => [ 1 .. 59 ],
+            Name       => 'TicketEscalationTimePoint',
+            SelectedID => $GetParam{TicketEscalationTimePoint},
+        );
+        $Param{TicketEscalationTimePointStart} = $Self->{LayoutObject}->BuildSelection(
+            Data => {
+                'Last'   => 'last',
+                'Before' => 'before',
+            },
+            Name => 'TicketEscalationTimePointStart',
+            SelectedID => $GetParam{TicketEscalationTimePointStart} || 'Last',
+        );
+        $Param{TicketEscalationTimePointFormat} = $Self->{LayoutObject}->BuildSelection(
+            Data => {
+                minute => 'minute(s)',
+                hour   => 'hour(s)',
+                day    => 'day(s)',
+                week   => 'week(s)',
+                month  => 'month(s)',
+                year   => 'year(s)',
+            },
+            Name       => 'TicketEscalationTimePointFormat',
+            SelectedID => $GetParam{TicketEscalationTimePointFormat},
+        );
+        $Param{TicketEscalationTimeStart} = $Self->{LayoutObject}->BuildDateSelection(
+            %GetParam,
+            Prefix   => 'TicketEscalationTimeStart',
+            Format   => 'DateInputFormat',
+            DiffTime => -( ( 60 * 60 * 24 ) * 30 ),
+        );
+        $Param{TicketEscalationTimeStop} = $Self->{LayoutObject}->BuildDateSelection(
+            %GetParam,
+            Prefix => 'TicketEscalationTimeStop',
+            Format => 'DateInputFormat',
+        );
+
         my %GetParamBackup = %GetParam;
-        for my $Key (qw(TicketClose TicketChange TicketCreate ArticleCreate)) {
+        for my $Key (qw(TicketEscalation TicketClose TicketChange TicketCreate ArticleCreate)) {
             for my $SubKey (qw(TimeStart TimeStop TimePoint TimePointStart TimePointFormat)) {
                 delete $GetParam{ $Key . $SubKey };
                 delete $GetParamBackup{ $Key . $SubKey };
@@ -2147,12 +2048,13 @@ sub Run {
             );
         }
 
-        # comapt. map for attributes
+        # compat. map for attributes
         my %Map = (
-            TimeSearchType        => 'TicketCreate',
-            ChangeTimeSearchType  => 'TicketChange',
-            CloseTimeSearchType   => 'TicketClose',
-            ArticleTimeSearchType => 'ArticleCreate',
+            TimeSearchType           => 'TicketCreate',
+            ChangeTimeSearchType     => 'TicketChange',
+            CloseTimeSearchType      => 'TicketClose',
+            EscalationTimeSearchType => 'TicketEscalation',
+            ArticleTimeSearchType    => 'ArticleCreate',
         );
         for my $Key ( sort keys %Map ) {
             next if !defined $GetParamBackup{$Key};
@@ -2203,10 +2105,21 @@ sub Run {
 
         # if no attribute is shown, show fulltext search
         if ( !$Profile ) {
-            if ( $Self->{Config}->{Defaults} ) {
-                for my $Key ( sort keys %{ $Self->{Config}->{Defaults} } ) {
+
+            # Merge regular show/hide settings and the settings for the dynamic fields
+            my %Defaults = %{ $Self->{Config}->{Defaults} || {} };
+            for my $DynamicField ( sort keys %{ $Self->{Config}->{DynamicField} || {} } ) {
+                if ( $Self->{Config}->{DynamicField}->{$DynamicField} == 2 ) {
+                    $Defaults{"Search_DynamicField_$DynamicField"} = 1;
+                }
+            }
+
+            if (%Defaults) {
+                for my $Key ( sort keys %Defaults ) {
+                    next if $Key eq 'DynamicField';    # Ignore entry for DF config
                     next if $AlreadyShown{$Key};
                     $AlreadyShown{$Key} = 1;
+
                     $Self->{LayoutObject}->Block(
                         Name => 'SearchAJAXShow',
                         Data => {
