@@ -1,8 +1,6 @@
 # --
 # Kernel/System/DynamicField/Backend.pm - Interface for DynamicField backends
-# Copyright (C) 2001-2013 OTRS AG, http://otrs.org/
-# --
-# $Id: Backend.pm,v 1.71.2.1 2013-01-10 15:43:33 ub Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -17,9 +15,6 @@ use warnings;
 use Scalar::Util qw(weaken);
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.71.2.1 $) [1];
-
 =head1 NAME
 
 Kernel::System::DynamicField::Backend
@@ -239,17 +234,11 @@ creates the field HTML to be used in edit masks.
         ConfirmationNeeded   => 0,                        # Optional, 0 or 1, default 0. To display a confirmation element
                                                           #     on fields that apply (like checkbox)
         AJAXUpdate           => 1,                        # Optional, 0 ir 1. To create JS code for field change to update
-                                                          #     the form using ACLs triggered by the field. Can't work with
-                                                          #     SubmitOnChange.
+                                                          #     the form using ACLs triggered by the field.
         UpdatableFields      => [                         # Optional, to use if AJAXUpdate is 1. List of fields to display a
             NetxStateID,                                  #     spinning wheel when reloading via AJAXUpdate.
             PriorityID,
         ],
-        SubmitOnChange       => 0,                        # Optional, 0 or 1, default 0. To set JS code to disable form
-                                                          #     validation and submit on change event. this is mostly used
-                                                          #     on customer interface to send dynamic field values to the
-                                                          #     server and calculate ACLs correctly. This feature is not
-                                                          #     available on all backends. Can't work with AJAXUpdate
     );
 
     Returns {
@@ -303,15 +292,6 @@ sub EditFieldRender {
         return;
     }
 
-    # check AJAXUpdate and SubmitOnChange
-    if ( $Param{AJAXUpdate} && $Param{SubmitOnChange} ) {
-        $Self->{LogObject}->Log(
-            Priority => 'error',
-            Message  => "Can't use AJAXUpdate and SubmitOnChange at the same time!"
-        );
-        return;
-    }
-
     # set the dynamic field specific backend
     my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
 
@@ -1360,8 +1340,8 @@ build the search parameters to be passed to the search engine.
                                                         #   Like              => 'value*',
                                                         #   GreaterThan       => '2001-01-01 01:01:01',
                                                         #   GreaterThanEquals => '2001-01-01 01:01:01',
-                                                        #   SmallerThan         => '2002-02-02 02:02:02',
-                                                        #   SmallerThanEquals   => '2002-02-02 02:02:02',
+                                                        #   SmallerThan       => '2002-02-02 02:02:02',
+                                                        #   SmallerThanEquals => '2002-02-02 02:02:02',
         },
         Display => $DisplayValue,                       # the value to be displayed in the search terms section
     };
@@ -1499,8 +1479,8 @@ build the search parameters to be passed to the search engine within the stats m
                                                         #   Like              => 'value*',
                                                         #   GreaterThan       => '2001-01-01 01:01:01',
                                                         #   GreaterThanEquals => '2001-01-01 01:01:01',
-                                                        #   SmallerThan         => '2002-02-02 02:02:02',
-                                                        #   SmallerThanEquals   => '2002-02-02 02:02:02',
+                                                        #   SmallerThan       => '2002-02-02 02:02:02',
+                                                        #   SmallerThanEquals => '2002-02-02 02:02:02',
         },
     };
 =cut
@@ -1981,7 +1961,7 @@ sub ObjectMatch {
         return;
     }
 
-    # do not perfom the action if the ObjectAttributes parameter is empty
+    # do not perform the action if the ObjectAttributes parameter is empty
     return if !IsHashRefWithData( $Param{ObjectAttributes} );
 
     # set the dynamic field specific backend
@@ -2135,6 +2115,77 @@ sub HistoricalValuesGet {
     );
 }
 
+=item ValueLookup()
+
+returns the display value for a value key for a defined Dynamic Field. This function is meaningfull
+for those Dynamic Fields that stores a value different than the value that is shown ( e.g. a
+Dropdown field could store Key = 1 and Display Value = One ) other fields return the same value
+as the value key
+
+    my $Value = $BackendObject->ValueLookup(
+        DynamicFieldConfig => $DynamicFieldConfig,       # complete config of the DynamicField
+        Key                => 'sotred value',             # could also be an array ref for
+                                                         #    MultipleSelect fields
+        LanguageObject     => $LanguageObject,            # optional, used to get value translations
+    );
+
+    Returns:
+
+    $Value = 'value to display';
+
+=cut
+
+sub ValueLookup {
+    my ( $Self, %Param ) = @_;
+
+    # check needed stuff
+    if ( !$Param{DynamicFieldConfig} ) {
+        $Self->{LogObject}->Log( Priority => 'error', Message => "Need DynamicFieldConfig!" );
+        return;
+    }
+
+    # check DynamicFieldConfig (general)
+    if ( !IsHashRefWithData( $Param{DynamicFieldConfig} ) ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "The field configuration is invalid",
+        );
+        return;
+    }
+
+    # check DynamicFieldConfig (internally)
+    for my $Needed (qw(ID FieldType ObjectType Config Name)) {
+        if ( !$Param{DynamicFieldConfig}->{$Needed} ) {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message  => "Need $Needed in DynamicFieldConfig!"
+            );
+            return;
+        }
+    }
+
+    # set the dynamic field specific backend
+    my $DynamicFieldBackend = 'DynamicField' . $Param{DynamicFieldConfig}->{FieldType} . 'Object';
+
+    if ( !$Self->{$DynamicFieldBackend} ) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message  => "Backend $Param{DynamicFieldConfig}->{FieldType} is invalid!"
+        );
+        return;
+    }
+
+    # remove LanguageObject param if is not a real LanguageObject
+    if ( defined $Param{LanguageObject} && ref $Param{LanguageObject} ne 'Kernel::Language' ) {
+        delete $Param{LanguageObject};
+    }
+
+    # call ValueLookup on the specific backend
+    return $Self->{$DynamicFieldBackend}->ValueLookup(
+        %Param,
+    );
+}
+
 1;
 
 =back
@@ -2148,9 +2199,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.71.2.1 $ $Date: 2013-01-10 15:43:33 $
-
-=cut
