@@ -1,8 +1,6 @@
 # --
 # Kernel/System/GenericAgent.pm - generic agent system module
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: GenericAgent.pm,v 1.81 2012/02/14 08:40:37 mg Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -18,9 +16,6 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw($VERSION);
-$VERSION = qw($Revision: 1.81 $) [1];
-
 =head1 NAME
 
 Kernel::System::GenericAgent - to manage the generic agent jobs
@@ -201,7 +196,7 @@ sub new {
 
         # Add field type to Map
         if ( IsHashRefWithData($FieldValueType) ) {
-            for my $FieldName ( keys %{$FieldValueType} ) {
+            for my $FieldName ( sort keys %{$FieldValueType} ) {
                 $Map{$FieldName} = $FieldValueType->{$FieldName};
             }
         }
@@ -266,7 +261,7 @@ sub JobRun {
         $Self->_JobUpdateRunTime( Name => $Param{Job}, UserID => $Param{UserID} );
 
         # rework
-        for my $Key ( keys %DBJobRaw ) {
+        for my $Key ( sort keys %DBJobRaw ) {
             if ( $Key =~ /^New/ ) {
                 my $NewKey = $Key;
                 $NewKey =~ s/^New//;
@@ -327,10 +322,12 @@ sub JobRun {
     # escalation tickets
     if ( $Job{Escalation} ) {
 
+        # Find all tickets which will escalate within the next five days.
+        #   The notification module will determine if a notification must be sent out or not.
         my @Tickets = $Self->{TicketObject}->TicketSearch(
             Result                           => 'ARRAY',
             Limit                            => 100,
-            TicketEscalationTimeOlderMinutes => -( 3 * 8 * 60 ),       # 3 days, roughly
+            TicketEscalationTimeOlderMinutes => -( 5 * 24 * 60 ),
             Permission                       => 'rw',
             UserID                           => $Param{UserID} || 1,
         );
@@ -406,7 +403,7 @@ sub JobRun {
                 %Tickets
             );
         }
-        for ( keys %Tickets ) {
+        for ( sort keys %Tickets ) {
             my %Ticket = $Self->{TicketObject}->TicketGet(
                 TicketID      => $_,
                 DynamicFields => 0,
@@ -423,14 +420,14 @@ sub JobRun {
 
             # check min. one search arg
             my $Count = 0;
-            for ( keys %Job ) {
+            for ( sort keys %Job ) {
                 if ( $_ !~ /^(New|Name|Valid|Schedule)/ && $Job{$_} ) {
                     $Count++;
                 }
             }
 
             # also search in Dynamic fields search attributes
-            for my $DynamicFieldName ( keys %DynamicFieldSearchParameters ) {
+            for my $DynamicFieldName ( sort keys %DynamicFieldSearchParameters ) {
                 $Count++;
             }
 
@@ -558,7 +555,7 @@ sub JobGet {
             $Data{ $Row[0] } = $Row[1];
         }
     }
-    for my $Key ( keys %Data ) {
+    for my $Key ( sort keys %Data ) {
         if ( $Key =~ /(NewParam)Key(\d)/ ) {
             if ( $Data{"$1Value$2"} ) {
                 $Data{"New$Data{$Key}"} = $Data{"$1Value$2"};
@@ -719,7 +716,7 @@ sub JobAdd {
     }
 
     # insert data into db
-    for my $Key ( keys %{ $Param{Data} } ) {
+    for my $Key ( sort keys %{ $Param{Data} } ) {
         if ( ref $Param{Data}->{$Key} eq 'ARRAY' ) {
             for my $Item ( @{ $Param{Data}->{$Key} } ) {
                 if ( defined $Item ) {
@@ -1249,7 +1246,7 @@ sub _JobUpdateRunTime {
         ),
         ScheduleLastRunUnixTime => $Self->{TimeObject}->SystemTime(),
     );
-    for my $Key ( keys %Insert ) {
+    for my $Key ( sort keys %Insert ) {
         $Self->{DBObject}->Do(
             SQL => 'INSERT INTO generic_agent_jobs (job_name,job_key, job_value) VALUES (?, ?, ?)',
             Bind => [ \$Param{Name}, \$Key, \$Insert{$Key} ],
@@ -1282,9 +1279,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.81 $ $Date: 2012/02/14 08:40:37 $
-
-=cut
