@@ -1,8 +1,6 @@
 # --
 # Kernel/System/GenericInterface/ObjectLockState.pm - backend for lock state handling
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: ObjectLockState.pm,v 1.5 2012/11/20 15:49:09 mh Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -14,8 +12,7 @@ package Kernel::System::GenericInterface::ObjectLockState;
 use strict;
 use warnings;
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.5 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -391,9 +388,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.5 $ $Date: 2012/11/20 15:49:09 $
-
-=cut
