@@ -1,8 +1,6 @@
 # --
 # Kernel/System/TemplateGenerator.pm - generate salutations, signatures and responses
-# Copyright (C) 2001-2012 OTRS AG, http://otrs.org/
-# --
-# $Id: TemplateGenerator.pm,v 1.69 2012/11/20 15:39:26 mh Exp $
+# Copyright (C) 2001-2013 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -26,8 +24,7 @@ use Kernel::System::DynamicField;
 use Kernel::System::DynamicField::Backend;
 use Kernel::System::VariableCheck qw(:all);
 
-use vars qw(@ISA $VERSION);
-$VERSION = qw($Revision: 1.69 $) [1];
+use vars qw(@ISA);
 
 =head1 NAME
 
@@ -622,11 +619,11 @@ sub AutoResponse {
     # format body (only if longer the 86 chars)
     if ( $Param{OrigHeader}->{Body} ) {
         if ( length $Param{OrigHeader}->{Body} > 86 ) {
-            my @lines = split /\n/, $Param{OrigHeader}->{Body};
-            for my $line (@lines) {
-                $line =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
+            my @Lines = split /\n/, $Param{OrigHeader}->{Body};
+            for my $Line (@Lines) {
+                $Line =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
             }
-            $Param{OrigHeader}->{Body} = join '', @lines;
+            $Param{OrigHeader}->{Body} = join '', @Lines;
         }
     }
 
@@ -783,11 +780,11 @@ sub NotificationAgent {
     # format body (only if longer the 86 chars)
     if ( $Param{CustomerMessageParams}->{Body} ) {
         if ( length $Param{CustomerMessageParams}->{Body} > 86 ) {
-            my @lines = split /\n/, $Param{CustomerMessageParams}->{Body};
-            for my $line (@lines) {
-                $line =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
+            my @Lines = split /\n/, $Param{CustomerMessageParams}->{Body};
+            for my $Line (@Lines) {
+                $Line =~ s/(^>.+|.{4,86})(?:\s|\z)/$1\n/gm;
             }
-            $Param{CustomerMessageParams}->{Body} = join '', @lines;
+            $Param{CustomerMessageParams}->{Body} = join '', @Lines;
         }
     }
 
@@ -844,6 +841,7 @@ sub NotificationAgent {
         TicketID    => $Param{TicketID},
         UserID      => $Param{UserID},
         Language    => $Language,
+        LastCustomerArticle     => \%Article,
     );
     $Notification{Subject} = $Self->_Replace(
         RichText    => 0,
@@ -1324,8 +1322,25 @@ sub _Replace {
         # replace <OTRS_CUSTOMER_EMAIL[]> tags
         $Tag = $Start . 'OTRS_CUSTOMER_EMAIL';
         if ( $Param{Text} =~ /$Tag\[(.+?)\]$End/g ) {
+            # This tag should include the message body
+            # of the last customer message.
+            # 
+            # In $Data{Body} it may happen that 
+            # the currents article Body gets passed down here.
+            # 
+            # So we have to use the Body of the $Param{Article}
+            # hash holding the article of the last customer message.
+            my $CustomerEmailBody = $Data{Body};
+
+            if ( $Param{LastCustomerArticle} 
+                && ref $Param{LastCustomerArticle} eq 'HASH'
+                && $Param{LastCustomerArticle}->{Body} 
+                && length $Param{LastCustomerArticle}->{Body} ) {
+                $CustomerEmailBody = $Param{LastCustomerArticle}->{Body};
+            }
+
             my $Line       = $1;
-            my @Body       = split( /\n/, $Data{Body} );
+            my @Body       = split( /\n/, $CustomerEmailBody );
             my $NewOldBody = '';
             for ( my $i = 0; $i < $Line; $i++ ) {
 
@@ -1388,7 +1403,7 @@ sub _Replace {
         $Tag = $Start . 'OTRS_EMAIL_DATE';
         if ( $Param{Text} =~ /$Tag\[(.+?)\]$End/g ) {
             my $TimeZone = $1;
-            my $EmailDate = strftime( '%A, %B %e, %Y at %T ', localtime );
+            my $EmailDate = strftime( '%A, %B %e, %Y at %T ', localtime );    ## no critic
             $EmailDate .= "($TimeZone)";
             $Param{Text} =~ s/$Tag\[.+?\]$End/$EmailDate/g;
         }
@@ -1468,9 +1483,3 @@ the enclosed file COPYING for license information (AGPL). If you
 did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
-
-=head1 VERSION
-
-$Revision: 1.69 $ $Date: 2012/11/20 15:39:26 $
-
-=cut
